searchData={"items":[{"type":"task","title":"mix multi_select.install","doc":"Installs multi_select component in the existing project.\n\n```bash\n$ mix multi_select.install\n```","ref":"Mix.Tasks.MultiSelect.Install.html"},{"type":"module","title":"Phoenix.LiveView.Components.MultiSelect","doc":"Multi-select component for Phoenix LiveView.\n\nUse in your HEEX templates with:\n```\n<.multi_select\n  id=\"multi\"\n  options={\n    %{id: 1, label: \"One\"},\n    %{id: 2, label: \"Two\"},\n  }\n>\n```\n\nSee `multi_select/1` for details.","ref":"Phoenix.LiveView.Components.MultiSelect.html"},{"type":"function","title":"Phoenix.LiveView.Components.MultiSelect.multi_select/1","doc":"MultiSelect LiveView stateful component.\n\nThe component implements a number of configuration options:\n\n  * `:id` - the required unique ID of the HTML element for this component\n\n  * `:debounce` - the integer controlling a `phx-debounce` value for the\n    search input\n\n  * `:options` - a required list of `%{id: any(), label: string()}` options to\n    select from\n\n  * `:form` - the required form name owning this component\n\n  * `:on_change` - a lambda `(options :: [%Multiselect.Option{}]) -> ok`\n    called on change of selected items\n\n  * `:class` - class added to the main `div` of the component\n  * `:max_selected` - max number of selected items\n  * `:wrap` - allow to wrap selected tags to multiple lines\n  * `:title` - component's title to use as the tooltip\n  * `:placeholder` - component's placeholder text\n  * `:search_placeholder` - placeholder for the search input box\n  * `:search_cbox_titles` - titles `on|off` of the checked icon in the search checkbox\n    (default: \"Clear filter of selected items|Filter selected items\")\n  * `:filter_side` - apply item filtering on client or server (default: client)","ref":"Phoenix.LiveView.Components.MultiSelect.html#multi_select/1"},{"type":"function","title":"Attributes - Phoenix.LiveView.Components.MultiSelect.multi_select/1","doc":"* `id` (`:string`) (required)\n* `debounce` (`:integer`) - Defaults to `350`.\n* `options` (`:list`) - List of `%{id: String.t, label: String.t}` maps. Defaults to `[]`.\n* `form` (`:any`) (required)\n* `on_change` (`:any`) - Lambda `(options) -> ok` to be called on selecting items.\n* `class` (`:string`) - Defaults to `nil`.\n* `max_selected` (`:integer`) - Max number of items selected. Defaults to `nil`.\n* `max_shown` (`:integer`) - Max number of shown selected tags. Defaults to `100000`.\n* `wrap` (`:boolean`) - Permit multiline wrapping of selected items. Defaults to `false`.\n* `title` (`:string`) - Component tooltip title. Defaults to `nil`.\n* `placeholder` (`:string`) - Placeholder shown on empty input. Defaults to `\"Select...\"`.\n* `search_placeholder` (`:string`) - Placeholder for the search input. Defaults to `\"Search...\"`.\n* `search_cbox_titles` (`:string`) - Titles `on|off` of the checked icon in the search checkbox. Defaults to `\"Clear filter of selected items|Filter selected items\"`.\n* `filter_side` (`:atom`) - Defaults to `:client`.\n* `selected_items_label` (`:string`) - Label to use when tags are not wrapped. Defaults to `\"items selected\"`.","ref":"Phoenix.LiveView.Components.MultiSelect.html#multi_select/1-attributes"},{"type":"function","title":"Phoenix.LiveView.Components.MultiSelect.update_settings/2","doc":"Call this function to notify the LiveView to update the settings of the\nmulti_select component identified by the `id`.","ref":"Phoenix.LiveView.Components.MultiSelect.html#update_settings/2"},{"type":"module","title":"Phoenix.LiveView.Components.MultiSelect.Option","doc":"","ref":"Phoenix.LiveView.Components.MultiSelect.Option.html"},{"type":"function","title":"Phoenix.LiveView.Components.MultiSelect.Option.__struct__/0","doc":"The option struct can be used for passing a list of option values to the\n`multi_select` component.","ref":"Phoenix.LiveView.Components.MultiSelect.Option.html#__struct__/0"},{"type":"function","title":"Phoenix.LiveView.Components.MultiSelect.Option.new/1","doc":"","ref":"Phoenix.LiveView.Components.MultiSelect.Option.html#new/1"},{"type":"type","title":"Phoenix.LiveView.Components.MultiSelect.Option.t/0","doc":"","ref":"Phoenix.LiveView.Components.MultiSelect.Option.html#t:t/0"},{"type":"extras","title":"Phoenix LiveView MultiSelect Component","doc":"# Phoenix LiveView MultiSelect Component\n\nThis project implements an Elixir Phoenix LiveView component that has a capability\nof selecting multiple check-boxed items from a list.\n\n![Example](https://user-images.githubusercontent.com/272543/214661918-110505f2-e796-40e3-a1ee-47178cb0daba.png)\n\nThe component supports the following options:\n\n- Selection of multiple items from the given list of options\n- Limit the max number of selected items\n- Ability to either wrap the selected tags in the main div of the component or\n  collapse them in a single tag\n- Ability to search in the list of options on the client side or on the server\n  side\n- Support of light/dark color themes\n- Support of AlpineJS and LiveView.JS javascript libraries\n\nHere's a sample [video](https://youtu.be/TfcgxACXWiM) illustrating what this component looks like in action.\n\nThis component is inspired by [this article](https://fly.io/phoenix-files/liveview-multi-select) but is a complete rewrite with added features for\nusability.","ref":"readme.html"},{"type":"extras","title":"Author - Phoenix LiveView MultiSelect Component","doc":"Serge Aleynikov","ref":"readme.html#author"},{"type":"extras","title":"Installation - Phoenix LiveView MultiSelect Component","doc":"Include the project in the `mix.exs` as a dependency:\n\n```elixir\ndefp deps do\n  [\n    {:phoenix_multi_select, \"~> 0.1\"},\n    ...\n  ]\n```\n\nRun `mix deps.get`, and `mix multi_select.install`. This will modify the following\nfiles:\n\n- `assets/tailwind.config.js` - to add the necessary color alias, and search path\n- `assets/package.json` - to add the tailwind scrollbar customization\n- `assets/js/hooks/multi-select-hook.js` - copied from the multi_select source\n- `assets/js/hooks/index.js` - add the MultiSelectHook\n\nInstall the javascript packages with your preferred package manager e.g `cd assets && npm install` or `cd assets && yarn install`\n\nIf the AlpineJS support is requested (`:use_alpinejs` options), the `root.html.heex`\nand `app.js` will be checked for installation of AlpineJS.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Phoenix LiveView MultiSelect Component","doc":"In your `assets/js/app.js` be sure to add the `hooks` entry with the live socket\ninitialization:\n\n```javascript\nimport hooks from \"./hooks\" // <--- add this line\n...\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  params: { _csrf_token: csrfToken },\n  hooks: hooks, // <--- add this line\n});\n```\n\nIn your project locate this file `{{your_project}}_web.ex`, and add:\n\n```elixir\n  defp html_helpers do\n    quote do\n      ...\n      import Phoenix.LiveView.Components.MultiSelect   ## <--- add this line\n      ...\n    end\n  end\n```\n\nNow in the `*.html.heex` templates you can use the `multi_select` LiveView\ncomponent like this:\n\n```elixir\n<.multi_select\n  id=\"some-id\"\n  options={[\n    %{id: 1, label: \"Option1\"},\n    %{id: 2, label: \"Option2\"},\n    ...\n  ]}\n/>\n```\n\nFor list of the available component's options see\n`Phoenix.LiveView.Components.MultiSelect.multi_select/1`","ref":"readme.html#usage"},{"type":"extras","title":"Customization (`config.exs` file) - Phoenix LiveView MultiSelect Component","doc":"- In order to add a custom class name to the `multi_select` component that will be\n  added to the top-most `div` element, and that it can be customized in your CSS files,\n  add the following configuration option:\n\n```elixir\nconfig :phoenix_multi_select,\n  class_prefix: \"some-class-name\"\n```\n\n- You can also override the build-in CSS classes for every aspect of the\n  component's presentation by defining a custom callback module, that implements\n  a `apply_css/3` function, which will be called to get a string of CSS classes\n  for every part of the component. Here is an example where the `primary` color\n  is replaced by `pink`. The first argument to the `apply_css/3` function is\n  the ID of the element that needs to apply customization. This way if the page\n  has multiple multi selects, they can be styled differently. See the `@css`\n  attribute in\n  [multi_select.ex](https://github.com/saleyn/phx-multi-select/blob/main/lib/multi_select.ex#L125)\n  for the list of permissible `tag` values passed to the `apply_css/3` function.\n\n```elixir\nconfig :phoenix_multi_select,\n  class_module: MyModule\n```\n\nHere is an example of implementation of such a module:\n\n```elixir\nmy_module.ex:\n=============\ndefmodule MyModule do\n  def apply_css(_id, _tag, def_css_classes), do:\n    String.replace(def_css_classes, \"primary\", \"pink\")\nend\n```\n\n- In order to enable AlpineJS support instead of LiveView.JS, set this config option:\n\n```elixir\nconfig :phoenix_multi_select,\n  use_alpinejs: true\n```","ref":"readme.html#customization-config-exs-file"},{"type":"extras","title":"Demo - Phoenix LiveView MultiSelect Component","doc":"The demo project is located in the `examples/` directory, and can be compiled\nand run with:\n\n```bash\ncd examples\nmake\nmake run\n```\n\nNow you can visit [`localhost:4000`](http://localhost:4000) from your browser.","ref":"readme.html#demo"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}